Feedforward Closedloop Learning: Class Members - Functions

Feedforward Closedloop Learning

### - _ -

- __init__() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank , feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron

### - a -

- addNeuron() : feedforward_closedloop_learning.LayerThread

### - b -

- Bandpass() : Bandpass

### - c -

- calcNorm() : Bandpass
- calcOutput() : feedforward_closedloop_learning.Neuron , Neuron
- calcOutputs() : feedforward_closedloop_learning.Layer , Layer
- calcOutputThread() : feedforward_closedloop_learning.Neuron , Neuron
- calcPolesZeros() : Bandpass

### - d -

- dActivation() : feedforward_closedloop_learning.Neuron , Neuron
- doLearning() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron
- doLearningThread() : feedforward_closedloop_learning.Neuron , Neuron
- doMaxDet() : feedforward_closedloop_learning.Neuron , Neuron
- doMaxDetThread() : feedforward_closedloop_learning.Neuron , Neuron
- doNormaliseWeights() : feedforward_closedloop_learning.Layer , Layer
- doStep() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank , FeedforwardClosedloopLearning , FeedforwardClosedloopLearningWithFilterbank

### - f -

- FeedforwardClosedloopLearning() : FeedforwardClosedloopLearning
- FeedforwardClosedloopLearningWithFilterbank() : FeedforwardClosedloopLearningWithFilterbank
- filter() : Bandpass

### - g -

- getAverageOfWeightVector() : feedforward_closedloop_learning.Neuron , Neuron
- getBiasWeight() : feedforward_closedloop_learning.Neuron , Neuron
- getDecay() : feedforward_closedloop_learning.Neuron , Neuron
- getError() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron
- getEuclideanNormOfWeightVector() : feedforward_closedloop_learning.Neuron , Neuron
- getFilterOutput() : feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank
- getInfinityNormOfWeightVector() : feedforward_closedloop_learning.Neuron , Neuron
- getInput() : feedforward_closedloop_learning.Neuron , Neuron
- getLayer() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- getLayers() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- getManhattanNormOfWeightVector() : feedforward_closedloop_learning.Neuron , Neuron
- getMask() : feedforward_closedloop_learning.Neuron , Neuron
- getMaxWeightValue() : feedforward_closedloop_learning.Neuron , Neuron
- getMinWeightValue() : feedforward_closedloop_learning.Neuron , Neuron
- getNeuron() : feedforward_closedloop_learning.Layer , Layer
- getNFiltersPerInput() : feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank
- getNinputs() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron
- getNneurons() : feedforward_closedloop_learning.Layer , Layer
- getNumInputs() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- getNumLayers() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- getOutput() : Bandpass , feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , FeedforwardClosedloopLearning , Layer , Neuron
- getOutputLayer() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- getSum() : feedforward_closedloop_learning.Neuron , Neuron
- getSumOfSquaredWeightVector() : feedforward_closedloop_learning.Neuron , Neuron
- getWeight() : feedforward_closedloop_learning.Neuron , Neuron
- getWeightDistanceFromInitialWeights() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron

### - i -

- impulse() : Bandpass
- initWeights() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , FeedforwardClosedloopLearning , Layer , Neuron

### - j -

- join() : feedforward_closedloop_learning.LayerThread

### - l -

- Layer() : Layer
- loadModel() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning

### - n -

- Neuron() : Neuron
- normaliseWeights() : feedforward_closedloop_learning.Neuron , Neuron

### - r -

- reset() : Bandpass
- run() : feedforward_closedloop_learning.LayerThread

### - s -

- saveInitialWeights() : feedforward_closedloop_learning.Neuron , Neuron
- saveModel() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- saveWeightMatrix() : feedforward_closedloop_learning.Layer , Layer
- seedRandom() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- setActivationFunction() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , FeedforwardClosedloopLearning , Layer , Neuron
- setBias() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , FeedforwardClosedloopLearning , Layer , Neuron
- setBiasWeight() : feedforward_closedloop_learning.Neuron , Neuron
- setConvolution() : feedforward_closedloop_learning.Layer , Layer
- setDebugInfo() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron
- setDecay() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , FeedforwardClosedloopLearning , Layer , Neuron
- setError() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron
- setErrors() : feedforward_closedloop_learning.Layer , Layer
- setGeometry() : feedforward_closedloop_learning.Neuron , Neuron
- setInput() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron
- setInputs() : feedforward_closedloop_learning.Layer , Layer
- setLearningRate() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , FeedforwardClosedloopLearning , Layer , Neuron
- setLearningRateDiscountFactor() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- setMask() : feedforward_closedloop_learning.Neuron , Neuron
- setMaxDetLayer() : feedforward_closedloop_learning.Layer , Layer
- setMomentum() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , FeedforwardClosedloopLearning , Layer , Neuron
- setNormaliseWeights() : feedforward_closedloop_learning.Layer , Layer
- setParameters() : Bandpass
- setStep() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron
- setUseThreads() : feedforward_closedloop_learning.Layer , Layer
- setWeight() : feedforward_closedloop_learning.Neuron , Neuron
- start() : feedforward_closedloop_learning.LayerThread

### - t -

- transfer() : Bandpass

### - ~ -

- ~FeedforwardClosedloopLearning() : FeedforwardClosedloopLearning
- ~FeedforwardClosedloopLearningWithFilterbank() : FeedforwardClosedloopLearningWithFilterbank
- ~Layer() : Layer
- ~Neuron() : Neuron